@@ -1,3 +1,4 @@
+from operator import truediv
 import os
 import click
 import requests
@@ -74,6 +75,13 @@ class CognitoAuth:
     self._code = None
     self._code_verifier = None
 
+  def is_authd(self) -> bool:
+    try:
+      self.get_or_refresh_token()
+      return True
+    except Exception:
+      return False
+
   def fetch_new_tokens(self) -> None:
     try:
       webbrowser.get()
