@@ -60,17 +60,6 @@ class ShareMagic(Magics):
 
   @cell_magic("share")
   def cmagic(self, line="", cell=""):
-    try:
-      auth = CognitoAuth()
-      auth.get_or_refresh_token()
-    except Exception:
-      # Fallback to inline log-in if no valid token
-      try:
-        instance = CONFIG.instance
-      except Exception:
-        instance = '1000words-hq.com'
-      login(instance)
-
     lines = cell.split('\n')
     try:
       undefs = resolveUndefined(cell)
@@ -81,7 +70,7 @@ class ShareMagic(Magics):
     client = Client()
     def puts3(name, data):
       with Status(f"Uploading dependency '{name}'"):
-        return client.put_protected(str(uuid.uuid4()), data)
+        return client.upload(str(uuid.uuid4()), data)
     srz = Serializer(puts3)
     vnames = list(set([u.message_args[0] for u in undefs]))
     for vname in vnames:
